==> sleet-0.1.dev6-py3-none-any.whl: sleet/hearthstone/api.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

from typing import Any

from sleet.base import BaseAPI


class HearthstoneAPI(BaseAPI):

    def __init__(self, client_id: str, client_secret: str, region: str):
        super().__init__(region=region, client_id=client_id, client_secret=client_secret)

    # Cards APIs
    def card_search(self, **kwargs: dict) -> dict[str, Any]:
        """
        Returns an up-to-date list of all cards matching the search criteria. (eg. health, attack, manaCost)
        """
        url = "/hearthstone/cards"

        return self.request(url, kwargs, None)

    def fetch_one_card(self, id_or_slug: int | str) -> dict[str, Any]:
        """
        Returns the card with an ID or slug that matches the one you specify.
        """
        url = f"/hearthstone/cards/{id_or_slug}"

        return self.request(url, None, None)

    # Card Backs APIs
    def card_back_search(self, **kwargs: dict) -> dict[str, Any]:
        """
        Returns an up-to-date list of all card backs matching the search criteria. (eg. cardBackCategory)
        """
        url = "/hearthstone/cardbacks"

        return self.request(url, kwargs, None)

    def fetch_one_card_back(self, id_or_slug: int | str) -> dict[str, Any]:
        """
        Returns a specific card back by using card back ID or slug.
        """
        url = f"/hearthstone/cardbacks/{id_or_slug}"

        return self.request(url, None, None)

    # Decks APIs
    def get_deck_by_code(self, **kwargs: dict) -> dict[str, Any]:
        """
        Finds a deck by deck code.
        """
        url = "/hearthstone/deck"

        return self.request(url, kwargs, None)

    def get_deck_by_card_list(self, **kwargs: dict) -> dict[str, Any]:
        """
        Finds a deck by list of cards, including the hero.
        """
        url = "/hearthstone/deck"

        return self.request(url, kwargs, None)

    # Metadata APIs
    def all_metadata(self) -> dict[str, Any]:
        """
        Returns the card with an ID or slug that matches the one you specify.
        """
        url = "/hearthstone/metadata"

        return self.request(url, None, None)

    def specific_metadata(self, metadata_type: str) -> dict[str, Any]:
        """
        Returns information about just one type of metadata.
        """
        url = f"/hearthstone/metadata/{metadata_type}"

        return self.request(url, None, None)

==> sleet-1.0-py3-none-any.whl: sleet/hearthstone/api.py <==
"""
This Source Code Form is subject to the terms of the Mozilla Public License, v. 2.0.
If a copy of the MPL was not distributed with this file, You can obtain one at https://mozilla.org/MPL/2.0/.
"""

from typing import Any

from sleet.base import BaseAPI


class HearthstoneAPI(BaseAPI):

    def __init__(self, *, region: str, client_id: str, client_secret: str):
        super().__init__(region=region, client_id=client_id, client_secret=client_secret)

    # Cards APIs
    def card_search(self, **kwargs: dict) -> dict[str, Any]:
        """
        Returns an up-to-date list of all cards matching the search criteria. (eg. health, attack, manaCost)
        """
        resource = "/hearthstone/cards"

        return self._request(resource, kwargs, None)

    def fetch_one_card(self, id_or_slug: int | str) -> dict[str, Any]:
        """
        Returns the card with an ID or slug that matches the one you specify.
        """
        resource = f"/hearthstone/cards/{id_or_slug}"

        return self._request(resource, None, None)

    # Card Backs APIs
    def card_back_search(self, **kwargs: dict) -> dict[str, Any]:
        """
        Returns an up-to-date list of all card backs matching the search criteria. (eg. cardBackCategory)
        """
        resource = "/hearthstone/cardbacks"

        return self._request(resource, kwargs, None)

    def fetch_one_card_back(self, id_or_slug: int | str) -> dict[str, Any]:
        """
        Returns a specific card back by using card back ID or slug.
        """
        resource = f"/hearthstone/cardbacks/{id_or_slug}"

        return self._request(resource, None, None)

    # Decks APIs
    def get_deck_by_code(self, **kwargs: dict) -> dict[str, Any]:
        """
        Finds a deck by deck code.
        """
        resource = "/hearthstone/deck"

        return self._request(resource, kwargs, None)

    def get_deck_by_card_list(self, **kwargs: dict) -> dict[str, Any]:
        """
        Finds a deck by list of cards, including the hero.
        """
        resource = "/hearthstone/deck"

        return self._request(resource, kwargs, None)

    # Metadata APIs
    def all_metadata(self) -> dict[str, Any]:
        """
        Returns the card with an ID or slug that matches the one you specify.
        """
        resource = "/hearthstone/metadata"

        return self._request(resource, None, None)

    def specific_metadata(self, metadata_type: str) -> dict[str, Any]:
        """
        Returns information about just one type of metadata.
        """
        resource = f"/hearthstone/metadata/{metadata_type}"

        return self._request(resource, None, None)
